==> qterminal_0.8.0.orig.tar.xz: qterminal-0.8.0/src/fontdialog.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Petr Vanek                                      *
 *   petr@scribus.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef FONT_DIALOG
#define FONT_DIALOG

#include "ui_fontdialog.h"
#include "properties.h"



class FontDialog : public QDialog, public Ui::FontDialog
{
    Q_OBJECT
public:
    FontDialog(const QFont &f);
    QFont getFont();

private slots:
    void setFontSample();

};

#endif

==> qterminal_2.1.0.orig.tar.xz: qterminal-2.1.0/src/fontdialog.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Petr Vanek                                      *
 *   petr@scribus.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef FONT_DIALOG
#define FONT_DIALOG

#include "ui_fontdialog.h"
#include "properties.h"



class FontDialog : public QDialog, public Ui::FontDialog
{
    Q_OBJECT
public:
    FontDialog(const QFont &f);
    QFont getFont();

private slots:
    void setFontSample(const QFont &f);
    void setFontSize();

};

#endif
